//
//  ViewController.m
//  Cell下的视频播放器
//
//  Created by 邱沐泽 on 16/8/5.
//  Copyright © 2016年 邱沐泽. All rights reserved.
//

#import <MediaPlayer/MediaPlayer.h>
#import "ViewController.h"
#import "NewTableViewCell.h"
#import "NewVideo.h"
#import <objc/runtime.h>

@interface ViewController ()<UITableViewDelegate, UITableViewDataSource>

@property(strong, nonatomic)UITableView *tableView;

@property(strong, nonatomic)NewVideo* player;

@property(strong, nonatomic)NewTableViewCell *currentCell;

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    [self setNav];
    [self createTableView];
    
    [[NSNotificationCenter defaultCenter]addObserver:self selector:@selector(playingDone) name:MPMoviePlayerPlaybackDidFinishNotification object:nil];
}

- (void)dealloc {
    [[NSNotificationCenter defaultCenter]removeObserver:self];
}

- (void)setVideo: (UIView *)videoBackView path: (NSString *)path {
    
    
    
    NSURL *url = [NSURL URLWithString:path];
    if (!_player) {
        _player = NewVideo.singleVideo;
    }
    [videoBackView addSubview:_player.view];
    _player.view.frame = videoBackView.bounds;
    
    _player.contentURL = url;
    
    _player.controlStyle = MPMovieControlStyleDefault;
    _player.shouldAutoplay = YES;
    _player.repeatMode = MPMovieRepeatModeNone;
    _player.scalingMode = MPMovieScalingModeAspectFit;
    [_player setFullscreen:NO animated:YES];
    [_player prepareToPlay];
    [_player setCurrentPlaybackTime:0];
    [_player play];
}

- (void)setNav {
    self.title = @"视频";
}

- (void)createTableView {
    _tableView = [[UITableView alloc]initWithFrame:self.view.bounds style:UITableViewStylePlain];
    [self.view addSubview:_tableView];
    _tableView.dataSource = self;
    _tableView.delegate = self;
    [_tableView registerClass:[NewTableViewCell class] forCellReuseIdentifier:@"cell"];
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return 10;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    NewTableViewCell *cell = [_tableView dequeueReusableCellWithIdentifier:@"cell" forIndexPath:indexPath];
    cell.titleLabel.text = @"搞笑视频";
    cell.timeLabel.text = @"2016-5-16";
    [cell.videoBackButton addTarget:self action:@selector(showVideo:) forControlEvents:UIControlEventTouchUpInside];
    if (indexPath.row == 0) {
        cell.videoPath = @"http://bsyqncdn.miaopai.com/stream/t~gB32Ha~0TyT3~Uju8bqQ__.mp4";
    }
    else {
        cell.videoPath = @"http://www.w3school.com.cn/example/html5/mov_bbb.mp4";
    }
    objc_setAssociatedObject(cell.videoBackButton, @"xxxx", cell, OBJC_ASSOCIATION_RETAIN_NONATOMIC);
    cell.selectionStyle = UITableViewCellSelectionStyleNone;
    return cell;
}

- (void)showVideo: (UIButton *)sender {
    NewTableViewCell *cell = objc_getAssociatedObject(sender, @"xxxx");
    if (_currentCell) {
        if (_currentCell != cell) {
            // 判断播放状态
            if (_player.playbackState == MPMoviePlaybackStatePlaying) {
                [_player stop];
            }
            _currentCell = cell;
            [self setVideo:sender path:cell.videoPath];
        }
    }
    else {
        _currentCell = cell;
        [self setVideo:sender path:cell.videoPath];
    }
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return 8 + 25 + 8 + 200 + 8;
}

- (void)playingDone {
    [_player.view removeFromSuperview];
    _currentCell = nil;
}

- (void)scrollViewDidScroll:(UIScrollView*)scrollView {
    if (scrollView == self.tableView && _currentCell != nil) {
        NSArray *cellArray = self.tableView.visibleCells;
        if (![cellArray containsObject:_currentCell]) {
            [_player stop];
        }
    }
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
